Learn R Programming

couplr (version 1.0.10)

auto_encode_categorical: Automatically encode categorical variables

Description

Converts categorical variables to numeric representations suitable for matching. Currently supports binary variables (0/1) and ordered factors.

Usage

auto_encode_categorical(left, right, var)

Value

List with encoded left and right columns, plus encoding metadata

Arguments

left

Data frame of left units

right

Data frame of right units

var

Variable name to encode