new_lazy_cost_spec: Construct a lazy cost specification

View source: R/matching_lazy.R

new_lazy_cost_specR Documentation

Construct a lazy cost specification

Description

mode is the memory mode that resolved to this specification: "lazy", solved over every pair, or "implicit", solved by generating the pairs the answer turns out to need.

Usage

new_lazy_cost_spec(
  left_mat,
  right_mat,
  distance,
  sigma,
  weights,
  vars,
  mode = c("lazy", "implicit")
)

Value

An object of class "lazy_cost_spec".


couplr documentation built on Sept. 17, 2026, 1:08 a.m.