Learn R Programming

couplr (version 1.0.10)

print.lap_solve_batch_result: Print method for batch assignment results

Description

Prints a summary and the table of results for a batch of assignment problems solved with lap_solve_batch().

Usage

# S3 method for lap_solve_batch_result
print(x, ...)

Value

Invisibly returns the input object x.

Arguments

x

A lap_solve_batch_result object.

...

Additional arguments passed to print(). Currently ignored.