View source: R/matching_interop.R
| bal.tab.matching_result | R Documentation |
S3 method enabling cobalt::bal.tab() on couplr result objects.
Requires the cobalt package to be installed.
## S3 method for class 'matching_result'
bal.tab(x, left, right, ...)
## S3 method for class 'full_matching_result'
bal.tab(x, left, right, ...)
## S3 method for class 'cem_result'
bal.tab(x, left, right, ...)
## S3 method for class 'subclass_result'
bal.tab(x, data = NULL, ...)
x |
A couplr result object |
left |
Data frame of left (treated) units |
right |
Data frame of right (control) units |
... |
Additional arguments. Arguments named in |
data |
Data frame used for subclassification (for subclass_result only) |
These methods convert couplr results to the format cobalt expects
(a matchit-class object) and then delegate to cobalt's own
bal.tab.matchit() method. The cobalt package must be
installed but is not required for couplr to function.
A cobalt balance table object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.