| .balance_flow_read | R Documentation |
Read a solved balance flow
.balance_flow_read(index, flow)
A list with the matched pairs as left and right indices, the slack each finest category carried, and the transfers with the level they crossed at.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.